package com.ruoyi.project.VRdemo.controller;

import cn.dev33.satoken.stp.StpUtil;
import com.alibaba.fastjson2.JSONObject;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.framework.aspectj.lang.annotation.Anonymous;
import com.ruoyi.framework.aspectj.lang.annotation.Log;
import com.ruoyi.framework.aspectj.lang.enums.BusinessType;
import com.ruoyi.framework.web.controller.BaseController;
import com.ruoyi.framework.web.domain.AjaxResult;
import com.ruoyi.framework.web.page.TableDataInfo;
import com.ruoyi.project.VRdemo.domain.NoticeData;
import com.ruoyi.project.VRdemo.domain.vo.NoticeDataVo;
import com.ruoyi.project.VRdemo.service.INoticeDataService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

@RestController
@RequestMapping("/system/noticeData")
public class NoticeDataController extends BaseController
{
    @Autowired
    private INoticeDataService noticeDataService;

    /**
     * 查询notice列表
     */
    @PreAuthorize("@ss.hasAnyRoles('admin,xmg')")
    @GetMapping("/list")
    public TableDataInfo list(NoticeData noticeData)
    {
        Long companyId = getLoginUser().getCompanyId();
        noticeData.setCompanyId(companyId);

        startPage();
        List<NoticeData> list = noticeDataService.selectNoticeDataList(noticeData);
        return getDataTable(list);
    }

    @Anonymous
    @PostMapping("/notice")
    public AjaxResult LoadingApp(@RequestBody JSONObject jsonObject){
        Long companyAppId = Long.parseLong(jsonObject.getString("company_app_id"));
//        Long dataType = Long.parseLong(jsonObject.getString("data_type"));

        StpUtil.login(companyAppId);
        NoticeDataVo noticeDataVo = new NoticeDataVo();
        noticeDataVo.setCompanyId(companyAppId);
//        studyDataVo.setDataType(dataType);
        List<NoticeData> list = noticeDataService.selectNoticeDataListVo(noticeDataVo);
        if (list == null || list.size() == 0) {
            AjaxResult.error("获取数据失败");
        }

        AjaxResult ajax = AjaxResult.success();
        ajax.put("data", list);

        return ajax;
    }

    /**
     * 导出notice列表
     */
    @PreAuthorize("@ss.hasAnyRoles('admin,xmg')")
    @Log(title = "notice", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, NoticeData noticeData)
    {
        List<NoticeData> list = noticeDataService.selectNoticeDataList(noticeData);
        ExcelUtil<NoticeData> util = new ExcelUtil<NoticeData>(NoticeData.class);
        util.exportExcel(response, list, "notice数据");
    }

    /**
     * 获取notice详细信息
     */
    @PreAuthorize("@ss.hasAnyRoles('admin,xmg')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(noticeDataService.selectNoticeDataById(id));
    }

    /**
     * 新增notice
     */
    @PreAuthorize("@ss.hasAnyRoles('admin,xmg')")
    @Log(title = "notice", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody NoticeData noticeData)
    {
        if (!noticeDataService.checkUserNameUnique(noticeData))
        {
            return error("新增标题'" + noticeData.getTitle() + "'失败，该标题已存在");
        }
        Long companyId =getLoginUser().getCompanyId();
        noticeData.setCompanyId(companyId);
        return toAjax(noticeDataService.insertNoticeData(noticeData));
    }

    /**
     * 修改notice
     */
    @PreAuthorize("@ss.hasAnyRoles('admin,xmg')")
    @Log(title = "notice", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody NoticeData noticeData)
    {
        return toAjax(noticeDataService.updateNoticeData(noticeData));
    }

    /**
     * 删除notice
     */
    @PreAuthorize("@ss.hasAnyRoles('admin,xmg')")
    @Log(title = "notice", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(noticeDataService.deleteNoticeDataByIds(ids));
    }
}