package com.ruoyi.project.VRdemo.service.impl;

import java.util.List;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.project.VRdemo.domain.RegionDevelop;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.VRdemo.mapper.RegionDevelopMapper;
import com.ruoyi.project.VRdemo.service.IRegionDevelopService;

/**
 * 东南亚地区发展报告Service业务层处理
 *
 * @author ruoyi
 * @date 2024-10-30
 */
@Service
public class RegionDevelopServiceImpl implements IRegionDevelopService {

    private final RegionDevelopMapper regionDevelopMapper;

    public RegionDevelopServiceImpl(@Autowired RegionDevelopMapper regionDevelopMapper) {
        this.regionDevelopMapper = regionDevelopMapper;
    }

    /**
     * 查询东南亚地区发展报告
     *
     * @param id 东南亚地区发展报告主键
     * @return 东南亚地区发展报告
     */
    @Override
    public RegionDevelop selectRegionDevelopById(Long id) {
        return regionDevelopMapper.selectRegionDevelopById(id);
    }

    /**
     * 查询东南亚地区发展报告列表
     *
     * @param regionDevelop 东南亚地区发展报告
     * @return 东南亚地区发展报告
     */
    @Override
    public List<RegionDevelop> selectRegionDevelopList(RegionDevelop regionDevelop) {
        return regionDevelopMapper.selectRegionDevelopList(regionDevelop);
    }

    /**
     * 新增东南亚地区发展报告
     *
     * @param regionDevelop 东南亚地区发展报告
     * @return 结果
     */
    @Override
    public int insertRegionDevelop(RegionDevelop regionDevelop) {
        regionDevelop.setCreateTime(DateUtils.getNowDate());
        return regionDevelopMapper.insertRegionDevelop(regionDevelop);
    }

    /**
     * 修改东南亚地区发展报告
     *
     * @param regionDevelop 东南亚地区发展报告
     * @return 结果
     */
    @Override
    public int updateRegionDevelop(RegionDevelop regionDevelop) {
        regionDevelop.setUpdateTime(DateUtils.getNowDate());
        return regionDevelopMapper.updateRegionDevelop(regionDevelop);
    }

    /**
     * 批量删除东南亚地区发展报告
     *
     * @param ids 需要删除的东南亚地区发展报告主键
     * @return 结果
     */
    @Override
    public int deleteRegionDevelopByIds(Long[] ids) {
        return regionDevelopMapper.deleteRegionDevelopByIds(ids);
    }

    /**
     * 删除东南亚地区发展报告信息
     *
     * @param id 东南亚地区发展报告主键
     * @return 结果
     */
    @Override
    public int deleteRegionDevelopById(Long id) {
        return regionDevelopMapper.deleteRegionDevelopById(id);
    }

    /**
     * 导入数据
     *
     * @param dataList      数据列表
     * @param updateSupport 是否更新
     * @return 结果
     */
    @Override
    public String importData(List<RegionDevelop> dataList, boolean updateSupport) {
        BulkImportService<RegionDevelop> importService = new BulkImportService<RegionDevelop>() {
            @Override
            protected Long checkExistingItem(RegionDevelop item) {
                RegionDevelop RegionDevelop = regionDevelopMapper.selectRegionDevelopByTitle(item.getTitle());
                return RegionDevelop == null ? 0L : RegionDevelop.getId();
            }

            @Override
            protected boolean updateItem(RegionDevelop item, Long id) {
                item.setId(id);
                item.setUpdateBy(SecurityUtils.getLoginUser().getUsername());
                item.setUpdateTime(DateUtils.getNowDate());
                return regionDevelopMapper.updateRegionDevelop(item) > 0;
            }

            @Override
            protected boolean executeBatch(List<RegionDevelop> batchDataList) {
                return regionDevelopMapper.insertRegionDevelopDataList(batchDataList) > 0;
            }

            @Override
            protected String getItemTitle(RegionDevelop item) {
                return item.getTitle();
            }
        };

        return importService.importData(dataList, updateSupport);
    }
}
