package com.ruoyi.project.VRdemo.service.impl;

import java.util.List;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.project.VRdemo.domain.SpecialCollection;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.VRdemo.mapper.SpecialCollectionMapper;
import com.ruoyi.project.VRdemo.service.ISpecialCollectionService;

/**
 * 东南亚大型特藏Service业务层处理
 *
 * @author ruoyi
 * @date 2024-10-06
 */
@Service
public class SpecialCollectionServiceImpl implements ISpecialCollectionService {

    private final SpecialCollectionMapper specialCollectionMapper;

    public SpecialCollectionServiceImpl(@Autowired SpecialCollectionMapper specialCollectionMapper) {
        this.specialCollectionMapper = specialCollectionMapper;
    }

    /**
     * 查询东南亚大型特藏
     *
     * @param id 东南亚大型特藏主键
     * @return 东南亚大型特藏
     */
    @Override
    public SpecialCollection selectCollectionById(Long id) {
        return specialCollectionMapper.selectCollectionById(id);
    }

    /**
     * 查询东南亚大型特藏列表
     *
     * @param specialCollection 东南亚大型特藏
     * @return 东南亚大型特藏
     */
    @Override
    public List<SpecialCollection> selectCollectionList(SpecialCollection specialCollection) {
        return specialCollectionMapper.selectCollectionList(specialCollection);
    }

    /**
     * 新增东南亚大型特藏
     *
     * @param specialCollection 东南亚大型特藏
     * @return 结果
     */
    @Override
    public int insertCollection(SpecialCollection specialCollection) {
        specialCollection.setCreateTime(DateUtils.getNowDate());
        return specialCollectionMapper.insertCollection(specialCollection);
    }

    /**
     * 修改东南亚大型特藏
     *
     * @param specialCollection 东南亚大型特藏
     * @return 结果
     */
    @Override
    public int updateCollection(SpecialCollection specialCollection) {
        specialCollection.setUpdateTime(DateUtils.getNowDate());
        return specialCollectionMapper.updateCollection(specialCollection);
    }

    /**
     * 批量删除东南亚大型特藏
     *
     * @param ids 需要删除的东南亚大型特藏主键
     * @return 结果
     */
    @Override
    public int deleteCollectionByIds(Long[] ids) {
        return specialCollectionMapper.deleteCollectionByIds(ids);
    }

    /**
     * 删除东南亚大型特藏信息
     *
     * @param id 东南亚大型特藏主键
     * @return 结果
     */
    @Override
    public int deleteCollectionById(Long id) {
        return specialCollectionMapper.deleteCollectionById(id);
    }

    /**
     * 导入数据
     *
     * @param dataList      导入数据列表
     * @param updateSupport 是否更新已经存在的数据
     * @return 结果
     */
    @Override
    public String importData(List<SpecialCollection> dataList, boolean updateSupport) {
        BulkImportService<SpecialCollection> importService = new BulkImportService<SpecialCollection>() {
            @Override
            protected Long checkExistingItem(SpecialCollection item) {
                SpecialCollection specialCollection = specialCollectionMapper.selectCollectionByTitle(item.getTitle());
                return specialCollection == null ? 0L : specialCollection.getId();
            }

            @Override
            protected boolean updateItem(SpecialCollection item, Long id) {
                item.setId(id);
                item.setUpdateBy(SecurityUtils.getLoginUser().getUsername());
                item.setUpdateTime(DateUtils.getNowDate());
                return specialCollectionMapper.updateCollection(item) > 0;
            }

            @Override
            protected boolean executeBatch(List<SpecialCollection> batchDataList) {
                return specialCollectionMapper.insertCollectionDataList(batchDataList) > 0;
            }

            @Override
            protected String getItemTitle(SpecialCollection item) {
                return item.getTitle();
            }
        };

        return importService.importData(dataList, updateSupport);
    }
}
