package com.ruoyi.project.VRdemo.service.impl;

import com.ruoyi.common.constant.Constants;
import com.ruoyi.common.constant.UserConstants;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.common.utils.file.FileUtils;
import com.ruoyi.framework.config.RuoYiConfig;
import com.ruoyi.project.VRdemo.domain.StudyData;
import com.ruoyi.project.VRdemo.domain.StudyNationData;
import com.ruoyi.project.VRdemo.domain.vo.StudyNationDataVo;
import com.ruoyi.project.VRdemo.mapper.StudyNationDataMapper;
import com.ruoyi.project.VRdemo.service.IStudyNationDataService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.io.File;
import java.util.List;

@Service
public class StudyNationDataServiceImpl implements IStudyNationDataService {
    @Autowired
    private StudyNationDataMapper studyNationDataMapper;

    /**
     * 查询studyNation
     *
     * @param id studyNation主键
     * @return studyNation
     */
    @Override
    public StudyNationData selectStudyNationDataById(Long id) {
        return studyNationDataMapper.selectStudyNationDataById(id);
    }

    /**
     * 查询studyNation列表
     *
     * @param studyNationData studyNation
     * @return studyNation
     */
    @Override
    public List<StudyNationData> selectStudyNationDataList(StudyNationData studyNationData) {
        return studyNationDataMapper.selectStudyNationDataList(studyNationData);
    }

    /**
     * 新增studyNation
     *
     * @param studyNationData studyNation
     * @return 结果
     */
    @Override
    public int insertStudyNationData(StudyNationData studyNationData) {
        studyNationData.setCreateTime(DateUtils.getNowDate());
        return studyNationDataMapper.insertStudyNationData(studyNationData);
    }

    /**
     * 校验用户名称是否唯一
     *
     * @param studyNationData 用户信息
     * @return 结果
     */
    @Override
    public boolean checkUserNameUnique(StudyNationData studyNationData) {
        Long userId = StringUtils.isNull(studyNationData.getId()) ? -1L : studyNationData.getId();
        StudyNationData info = studyNationDataMapper.checkUserNameUnique(studyNationData.getTitle());
        if (StringUtils.isNotNull(info) && info.getId().longValue() != userId.longValue()) {
            return UserConstants.NOT_UNIQUE;
        }
        return UserConstants.UNIQUE;
    }

    /**
     * 修改studyNation
     *
     * @param studyNationData studyNation
     * @return 结果
     */
    @Override
    public int updateStudyNationData(StudyNationData studyNationData) {
        studyNationData.setUpdateTime(DateUtils.getNowDate());
        return studyNationDataMapper.updateStudyNationData(studyNationData);
    }

    /**
     * 批量删除studyNation
     *
     * @param ids 需要删除的studyNation主键
     * @return 结果
     */
    @Override
    public int deleteStudyNationDataByIds(Long[] ids) {
        return studyNationDataMapper.deleteStudyNationDataByIds(ids);
    }

    /**
     * 删除studyNation信息
     *
     * @param id studyNation主键
     * @return 结果
     */
    @Override
    public int deleteStudyNationDataById(Long id) {
        return studyNationDataMapper.deleteStudyNationDataById(id);
    }

    @Override
    public List<StudyNationData> selectStudyNationDataListVo(StudyNationDataVo studyNationDataVo) {
        return studyNationDataMapper.selectStudyNationDataListVo(studyNationDataVo);
    }

    @Override
    public List<StudyNationData> selectStudyNationDataListVoAll(StudyNationDataVo studyNationDataVo) {
        return studyNationDataMapper.selectStudyNationDataListVoAll(studyNationDataVo);
    }

    //删除
    public boolean deleteFile(Long ids) {
        // 根据ID查询文件信息
        StudyNationData file = studyNationDataMapper.selectStudyNationDataById(ids);
        System.out.println("4." + file);
        if (file == null) {
            return false; // 文件不存在，删除失败
        }

        String oldPath = file.getFilePath();
        if (oldPath != null) {
            String filePath = RuoYiConfig.getUploadPath();
            //由于在RuoYiConfig.getUploadPath()中带有upload导致文件搜索失败，所以去除
            String keyword = "/upload";
            int endIndex = filePath.indexOf(keyword);
            if (endIndex != -1) {
                filePath = filePath.substring(0, (filePath.length()-7));
            }

            String deletaPath = filePath + StringUtils.substringAfter(oldPath, Constants.RESOURCE_PREFIX);
            System.out.println("5." + deletaPath);
            if (deleteFileRecursive(deletaPath)) {
                // 执行特定文件夹删除操作
                String fileExtension = getFileExtensionFromPath(deletaPath);
                if (fileExtension.equalsIgnoreCase("pdf")) {
                    String subFolderPath = getSubFolderPath(deletaPath, "pdf");
                    System.out.println("8." + subFolderPath);
                    deleteFolder(subFolderPath); // 修改这一行
                } else if (fileExtension.equalsIgnoreCase("doc") || fileExtension.equalsIgnoreCase("docx")) {
                    String subFolderPath = getSubFolderPath(deletaPath, "word");
                    System.out.println("9." + subFolderPath);
                    deleteFolder(subFolderPath); // 修改这一行
                }

                // 删除数据库中的文件记录
                int deleteCount = studyNationDataMapper.deleteStudyNationDataById(ids);
                System.out.println("文件删除成功");
                return true; // 文件删除成功
            } else {
                System.out.println("文件删除失败");
                return false; // 文件删除失败
            }
        }
        return false;
    }

    //只删除文件
    public boolean updateOnlyFile(Long ids) {
        // 根据ID查询文件信息
        String newFile = "";
        StudyNationData file = studyNationDataMapper.selectStudyNationDataById(ids);
        String oldFile = file.getFilePath();
        if (oldFile != null) {
            String filePath = RuoYiConfig.getProfile();
            String deletaPath = filePath + StringUtils.substringAfter(oldFile, Constants.RESOURCE_PREFIX);
            if (FileUtils.deleteFile(deletaPath)) {
                boolean flag = studyNationDataMapper.updateFileUploadUrlData(newFile, ids);
                if (flag) {
                    return true;
                }
            }
        }
        return false;
    }

    // 从文件路径中获取文件扩展名
    private String getFileExtensionFromPath(String filePath) {
        int dotIndex = filePath.lastIndexOf(".");
        if (dotIndex >= 0 && dotIndex < filePath.length() - 1) {
            return filePath.substring(dotIndex + 1).toLowerCase();
        }
        System.out.println("10." + dotIndex);
        return "";
    }

    // 根据文件路径和指定的文件夹名称获取子文件夹路径
    private String getSubFolderPath(String filePath, String folderName) {
        int index = filePath.lastIndexOf(File.separator + folderName + File.separator);
        if (index != -1) {
            return filePath.substring(0, index);
        }
        return filePath;
    }


    /**
     * 删除文件
     *
     * @param ids 文件
     * @return
     */
    public static boolean deleteFileRecursive(String ids) {
        File file = new File(ids);
        System.out.println("11." + file.getPath());
        if (file.isFile() && file.exists()) {
            return file.delete();
        }
        System.out.println(false);
        return false;
    }

    // 递归删除文件夹及其内容
    private void deleteFolder(String filePath) {
        File folder = new File(filePath);
        System.out.println("12." + folder);
        if (folder.exists()) {
            File[] files = folder.listFiles();
            if (files != null) {
                for (File file : files) {
                    if (file.isDirectory()) {
                        deleteFolder(file.getPath()); // 使用完整的文件夹路径
                    } else {
                        file.delete();
                    }
                }
                folder.delete();
            }
        }
    }
}